==> ec2-0.19.0-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/VPCResource.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.11 (build 44c3b9b)", date = "2018-12-04T12:19:22.627Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.cloudformation.VPCResource")
public class VPCResource extends software.amazon.awscdk.Resource {
    protected VPCResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.cloudformation.VPCResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::VPC``.
     * @param parent the ``cdk.Construct`` this ``VPCResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``VPCResource``
     */
    public VPCResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.cloudformation.VPCResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.cloudformation.VPCResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.cloudformation.VPCResourceProps.class);
    }

    /**
     * @cloudformation_attribute CidrBlock
     */
    public java.lang.String getVpcCidrBlock() {
        return this.jsiiGet("vpcCidrBlock", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute CidrBlockAssociations
     */
    public software.amazon.awscdk.services.ec2.VPCCidrBlockAssociations getVpcCidrBlockAssociations() {
        return this.jsiiGet("vpcCidrBlockAssociations", software.amazon.awscdk.services.ec2.VPCCidrBlockAssociations.class);
    }

    /**
     * @cloudformation_attribute DefaultNetworkAcl
     */
    public java.lang.String getVpcDefaultNetworkAcl() {
        return this.jsiiGet("vpcDefaultNetworkAcl", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute DefaultSecurityGroup
     */
    public java.lang.String getVpcDefaultSecurityGroup() {
        return this.jsiiGet("vpcDefaultSecurityGroup", java.lang.String.class);
    }

    public java.lang.String getVpcId() {
        return this.jsiiGet("vpcId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Ipv6CidrBlocks
     */
    public software.amazon.awscdk.services.ec2.VPCIpv6CidrBlocks getVpcIpv6CidrBlocks() {
        return this.jsiiGet("vpcIpv6CidrBlocks", software.amazon.awscdk.services.ec2.VPCIpv6CidrBlocks.class);
    }
}

==> ec2-0.21.0-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/VPCResource.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @deprecated "cloudformation.VPCResource" will be deprecated in a future release in favor of "CfnVPC" (see https://github.com/awslabs/aws-cdk/issues/878)
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:30:42.003Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.cloudformation.VPCResource")
public class VPCResource extends software.amazon.awscdk.Resource {
    protected VPCResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.cloudformation.VPCResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::VPC``.
     * @param parent the ``cdk.Construct`` this ``VPCResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``VPCResource``
     */
    public VPCResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.cloudformation.VPCResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.cloudformation.VPCResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.cloudformation.VPCResourceProps.class);
    }

    /**
     * @cloudformation_attribute CidrBlock
     */
    public java.lang.String getVpcCidrBlock() {
        return this.jsiiGet("vpcCidrBlock", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute CidrBlockAssociations
     */
    public software.amazon.awscdk.services.ec2.VPCCidrBlockAssociations getVpcCidrBlockAssociations() {
        return this.jsiiGet("vpcCidrBlockAssociations", software.amazon.awscdk.services.ec2.VPCCidrBlockAssociations.class);
    }

    /**
     * @cloudformation_attribute DefaultNetworkAcl
     */
    public java.lang.String getVpcDefaultNetworkAcl() {
        return this.jsiiGet("vpcDefaultNetworkAcl", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute DefaultSecurityGroup
     */
    public java.lang.String getVpcDefaultSecurityGroup() {
        return this.jsiiGet("vpcDefaultSecurityGroup", java.lang.String.class);
    }

    public java.lang.String getVpcId() {
        return this.jsiiGet("vpcId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Ipv6CidrBlocks
     */
    public software.amazon.awscdk.services.ec2.VPCIpv6CidrBlocks getVpcIpv6CidrBlocks() {
        return this.jsiiGet("vpcIpv6CidrBlocks", software.amazon.awscdk.services.ec2.VPCIpv6CidrBlocks.class);
    }
}
